@@ -1,12 +1,12 @@
 package Term::YAP::iThread;
-
+$Term::YAP::iThread::VERSION = '0.04';
 use strict;
 use warnings;
-use threads;
-use Thread::Queue;
-use Types::Standard qw(InstanceOf Bool);
-use Moo;
-use namespace::clean;
+use threads 2.01;
+use Thread::Queue 3.05;
+use Types::Standard 1.000005 qw(InstanceOf Bool);
+use Moo 2.000002;
+use namespace::clean 0.26;
 
 extends 'Term::YAP';
 
